@@ -24,19 +24,15 @@ class ArcFace():
         """
 
         if config['face_embedding']['gpuid'] >= 0:
-            ctx = mx.gpu(config['face_embedding']['gpuid'])
+            self.ctx = mx.gpu(config['face_embedding']['gpuid'])
         else:
-            ctx = mx.cpu()
+            self.ctx = mx.cpu()
 
         self.image_size = tuple(config['face_embedding']['img_size'])
         self.model = None
-        self.ga_model = None
-        if config['face_embedding']['weight']:
-            self.model = self.get_model(ctx, self.image_size, config['face_embedding']['weight'], 'fc1')
 
-        self.threshold = config['face_embedding']['threshold']
-        self.det_minsize = 50
-        self.det_threshold = [0.6, 0.7, 0.8]
+        if config['face_embedding']['weight']:
+            self.model = self.get_model(self.ctx, self.image_size, config['face_embedding']['weight'], 'fc1')
 
     def get_model(self, ctx, image_size, model_str, layer):
         """ Get the model """
